@@ -54,7 +54,7 @@ class TestDNSUpdates(DNSTKeyTest):
     def setUp(self):
         self.server = server_name
         self.server_ip = server_ip
-        super(TestDNSUpdates, self).setUp()
+        super().setUp()
 
     def test_tkey_gss_tsig(self):
         "test DNS TKEY handshake with gss-tsig"
